##
##  lua51.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2015 OpenPKG Foundation e.V. <http://openpkg.net/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         lua51
Summary:      LUA Programming Language
URL:          http://www.lua.org/
Vendor:       Tecgraf
Packager:     OpenPKG Foundation e.V.
Distribution: OpenPKG Community
Class:        PLUS
Group:        Language
License:      MIT
Version:      5.1.5
Release:      20150114

#   package options
%option       with_readline  no

#   list of sources
Source0:      http://www.lua.org/ftp/lua-%{version}.tar.gz
Source1:      lua.pc
Patch0:       lua51.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20100101, gcc, make
PreReq:       OpenPKG, openpkg >= 20100101
%if "%{with_readline}" == "yes"
BuildPreReq:  readline, pkgconfig
PreReq:       readline
%endif

%description
    Lua is a powerful light-weight programming language designed
    for extending applications. Lua is also frequently used as a
    general-purpose, stand-alone language. Lua is free software. Lua
    combines simple procedural syntax with powerful data description
    constructs based on associative arrays and extensible semantics. Lua
    is dynamically typed, interpreted from bytecodes, and has automatic
    memory management with garbage collection, making it ideal for
    configuration, scripting, and rapid prototyping.

%track
    prog lua51 = {
        version   = %{version}
        url       = http://www.lua.org/ftp/
        regex     = lua-(5\.\1.\d+)\.tar\.gz
    }

%prep
    %setup -q -n lua-%{version}
    %patch -p0

%build
    %{l_shtool} subst \
        -e 's;/usr/local;%{l_prefix};g' \
        src/luaconf.h
    platform="posix"
    case "%{l_platform -t}" in
        *-linux*   ) platform="linux"   ;;
        *-freebsd* ) platform="bsd"     ;;
        *-sunos*   ) platform="solaris" ;;
    esac
    export MYCFLAGS=""
    export MYLIBS=""
%if "%{with_readline}" == "yes"
    MYCFLAGS="$MYCFLAGS -DLUA_USE_READLINE `pkg-config readline --cflags-only-I`"
    MYLIBS="$MYLIBS `pkg-config readline --libs-only-l`"
%endif
    %{l_make} %{l_mflags -O} \
        CC="%{l_cc} %{l_cflags -O}" \
        MYCFLAGS="$MYCFLAGS" \
        MYLIBS="$MYLIBS" \
        INSTALL_TOP="%{l_prefix}" \
        INSTALL_INC="\$(INSTALL_TOP)/include/lua51/lua" \
        INSTALL_LIB="\$(INSTALL_TOP)/lib/lua51" \
        $platform

%install
    %{l_make} %{l_mflags} install \
        INSTALL_TOP="$RPM_BUILD_ROOT%{l_prefix}" \
        INSTALL_INC="\$(INSTALL_TOP)/include/lua51/lua" \
        INSTALL_LIB="\$(INSTALL_TOP)/lib/lua51"
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/lib/pkgconfig
    libs="-llua"
    case "%{l_platform -t}" in
        *-sunos* ) libs="$libs -ldl" ;;
    esac
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        -e "s;@version@;%{version};g" \
        -e "s;@libs@;$libs;g" \
        %{SOURCE lua.pc} $RPM_BUILD_ROOT%{l_prefix}/lib/pkgconfig/lua51.pc
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/share/lua
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/lib/lua
    mv  $RPM_BUILD_ROOT%{l_prefix}/bin/lua \
        $RPM_BUILD_ROOT%{l_prefix}/bin/lua51
    mv  $RPM_BUILD_ROOT%{l_prefix}/bin/luac \
        $RPM_BUILD_ROOT%{l_prefix}/bin/luac51
    mv  $RPM_BUILD_ROOT%{l_prefix}/man/man1/lua.1 \
        $RPM_BUILD_ROOT%{l_prefix}/man/man1/lua51.1
    mv  $RPM_BUILD_ROOT%{l_prefix}/man/man1/luac.1 \
        $RPM_BUILD_ROOT%{l_prefix}/man/man1/luac51.1
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

